<?php

use  yii\web\Session;

class PackController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array('view','admin','check'),
				'roles'=>array('readPost'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array('create'),
				#'users'=>array('admin'),
				'roles'=>array('createPost'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array('update'),
				#'users'=>array('admin'),
				'roles'=>array('updatePost'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('delete','deleteall'),
				#'users'=>array('admin'),
				'roles'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}

	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		$this->render('view',array(
			'model'=>$this->loadModel($id),
		));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model=new Pack;

		// Uncomment the following line if AJAX validation is needed
		$this->performAjaxValidation($model);

		if(isset($_POST['Pack']))
		{
			$model->attributes=$_POST['Pack'];
			
			$root = dirname(Yii::app()->request->scriptFile);
			$dir = $root . '/package/assets/'.$model->identifier;
			if(file_exists($dir)){
				$this->delete_directory('package/assets/'.$model->identifier);
			}
			$old = umask(0);
			if( !is_dir($dir) ) {
				mkdir($dir, 0755, true);
			}
			umask($old);
			
			if($model->save())
				$this->redirect(array('update','id'=>$model->id));
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		$this->performAjaxValidation($model);

		if(isset($_POST['Pack']))
		{
			$model->attributes=$_POST['Pack'];
			if($model->save())
				$this->redirect(array('update','id'=>$model->id));
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}
	
	public function actionCheck()
	{
		$id = Yii::app()->request->getPost('id'); 
		
		$criteria = new CDbCriteria();
		$criteria->compare('title', $id, true, 'OR');
		$models=Pack::model()->findAll($criteria);
		if(count($models) > 0 ){
			echo "This identifier has already been added, please try a different name. This can cause errors.";
		}else {
			echo "Congratulations, This name is suitable.";
		}
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		$this->dizin_bosalt($id);
		$this->loadModel($id)->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
			$this->redirect(array('pack/create'));
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		$dataProvider=new CActiveDataProvider('Pack');
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));
	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new Pack('search');
		$model->unsetAttributes();  // clear any default values
		if(isset($_GET['Pack']))
			$model->attributes=$_GET['Pack'];

		$this->render('viewed_',array(
			'model'=>$model,
		));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer $id the ID of the model to be loaded
	 * @return Pack the loaded model
	 * @throws CHttpException
	 */
	public function loadModel($id)
	{
		$model=Pack::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param Pack $model the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='pack-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}
	
	public function ActionDeleteall(){
		$idAll=$_POST['id'];
		if(count($idAll)>0){
			foreach ($idAll as $id){
				#$this->dizin_bosalt($id);
				$this->loadModel($id)->delete();
			}
		}
	}
	
	public function dizin_bosalt($id){
		$model = Pack::model()->findByPk($id);
		$path= '/package/assets/'.$model->identifier.'/';
		
		$dizin=Yii::getPathOfAlias('webroot').$path;
		if(file_exists($dizin)){
			$this->delete_directory($dizin);
		}
	
	}
	
	public function delete_directory($dirname) {
	if (is_dir($dirname))
	  $dir_handle = opendir($dirname);
	if (!$dir_handle)
	  return false;
	while($file = readdir($dir_handle)) {
	  if ($file != "." && $file != "..") {
		 if (!is_dir($dirname."/".$file))
			unlink($dirname."/".$file);
		 else
			delete_directory($dirname.'/'.$file);    
	  }
	}
	closedir($dir_handle);
	rmdir($dirname);
	return true;
	}
}
