<?php

class StickerController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}
	
	function generateKeywordsFromText($text){


	// List of words NOT to be included in keywords
	$stopWords = array('stickers','sticker','whatsapp','i','a','about','an','and','are','as','at','be','by','com','de','en','for','from','how','in','is','it','la','of','on','or','that','the','this','to','was','what','when','where','who','will','with','und','the','www', "such", "have", "then");


	//Let us do some basic clean up! on the text before getting to real keyword generation work

	$text = preg_replace('/\s\s+/i', '', $text); // replace multiple spaces etc. in the text
	$text = trim($text); // trim any extra spaces at start or end of the text
	$text = preg_replace('/[^a-zA-Z0-9 -]/', '', $text); // only take alphanumerical characters, but keep the spaces and dashes too…
	$text = strtolower($text); // Make the text lowercase so that output is in lowercase and whole operation is case in sensitive.

	// Find all words
	preg_match_all('/\b.*?\b/i', $text, $allTheWords);
	$allTheWords = $allTheWords[0];

	//Now loop through the whole list and remove smaller or empty words
	foreach ( $allTheWords as $key=>$item ) {
	if ( $item == '' || in_array(strtolower($item), $stopWords) || strlen($item) <= 3 ) {
	  unset($allTheWords[$key]);
	}
	}   

	// Create array that will later have its index as keyword and value as keyword count.
	$wordCountArr = array();

	// Now populate this array with keywrds and the occurance count
	if ( is_array($allTheWords) ) {
	foreach ( $allTheWords as $key => $val ) {
	  $val = strtolower($val);
	  if ( isset($wordCountArr[$val]) ) {
		  $wordCountArr[$val]++;
	  } else {
		  $wordCountArr[$val] = 1;
	  }
	}
	}

	// Sort array by the number of repetitions
	arsort($wordCountArr);

	//Keep first 10 keywords, throw other keywords
	$wordCountArr = array_slice($wordCountArr, 0, 10);

	// Now generate comma separated list from the array
	$words="";
	foreach  ($wordCountArr as $key=>$value)
	$words .= ", " . $key ;

	// Trim list of comma separated keyword list and return the list
	return trim($words,",");
	}


	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array('view','admin'),
				'roles'=>array('readPost'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array('create'),
				#'users'=>array('admin'),
				'roles'=>array('createPost'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array('update'),
				#'users'=>array('admin'),
				'roles'=>array('updatePost'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('delete','deleteall'),
				#'users'=>array('admin'),
				'roles'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}
	
	/**
	 * @return string - pack_name
	 */
	public function getCategoryName($cid){
		// pack Model
		$pack=Pack::model()->findAll('id=:id', array(':id'=>$cid));
		foreach($pack as $key => $cat):
			// return pack_name
			return $cat->title;
		endforeach;
	}
	
	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		$this->render('view',array(
			'model'=>$this->loadModel($id),
		));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{	
		$length = 20;
		$chars = array_merge(range(0,20), range('a','z'), range('A','Z'));
		shuffle($chars);
		$identifier = implode(array_slice($chars, 0, $length));

		$model=new Sticker;

		// Uncomment the following line if AJAX validation is needed
		$this->performAjaxValidation($model);

		if(isset($_POST['Sticker']))
		{
			$model->attributes=$_POST['Sticker'];
			$model->identifier=$identifier;
			$model->tags=$this->generateKeywordsFromText($model->tags);
			$model->tag=$this->getCategoryName($model->category);
			if($model->save())
				$this->redirect(array('update','id'=>$model->id));
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{	
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		$this->performAjaxValidation($model);

		if(isset($_POST['Sticker']))
		{
			$model->attributes=$_POST['Sticker'];
			$model->tags=$this->generateKeywordsFromText($model->tags);
			$model->tag=$this->getCategoryName($model->category);
			if($model->save())
				$this->redirect(array('update','id'=>$model->id));
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		#$this->dizin_bosalt($id);
		$this->loadModel($id)->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
			$this->redirect(array('sticker/create'));
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		$dataProvider=new CActiveDataProvider('Sticker');
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));
	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new Sticker('search');
		$model->unsetAttributes();  // clear any default values
		if(isset($_GET['Sticker']))
			$model->attributes=$_GET['Sticker'];

		$this->render('viewed_',array(
			'model'=>$model,
		));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer $id the ID of the model to be loaded
	 * @return Sticker the loaded model
	 * @throws CHttpException
	 */
	public function loadModel($id)
	{
		$model=Sticker::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param Sticker $model the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='sticker-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}
	
	public function ActionDeleteall(){
		$idAll=$_POST['id'];
		if(count($idAll)>0){
			foreach ($idAll as $id){
				#$this->dizin_bosalt($id);
				$this->loadModel($id)->delete();
			}
		}
	}
	/*
	public function dizin_bosalt($id){
		$user=User::model()->find(array(
			'select'=>'avatar',
			'condition'=>'id=:id',
			'params'=>array(':id'=>$id),
		));
		if($user->avatar!=''){
			$dizin=Yii::getPathOfAlias('webroot').'/images/user/'.$user->avatar;
			if(file_exists($dizin)){
				unlink($dizin);
			}
		}
	}
	*/
}
