<?php

/**
 * This is the model class for table "configs".
 *
 * The followings are the available columns in table 'configs':
 * @property string $app_name
 * @property string $admob_banner_id
 * @property string $admob_interstitial_id
 * @property string $admob_rewarded_id
 * @property integer $admob_status
 * @property integer $app_version
 * @property string $app_message
 * @property string $app_purchase_code
 * @property integer $is_maintance
 * @property integer $id
 * @property string $serverkey
 * @property string $productid
 */
class Configs extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'configs';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('app_name, admob_banner_id, admob_interstitial_id, app_message, app_purchase_code, serverkey, productid', 'required'),
			array('admob_status, app_version, is_maintance', 'numerical', 'integerOnly'=>true),
			array('app_name, productid', 'length', 'max'=>100),
			array('admob_banner_id, admob_interstitial_id, admob_rewarded_id, app_message, app_purchase_code', 'length', 'max'=>225),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('app_name, admob_banner_id, admob_interstitial_id, admob_rewarded_id, admob_status, app_version, app_message, app_purchase_code, is_maintance, id, serverkey, productid', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'app_name' => 'App Name',
			'admob_banner_id' => 'Admob Banner',
			'admob_interstitial_id' => 'Admob Interstitial',
			'admob_rewarded_id' => 'Admob Rewarded',
			'admob_status' => 'Admob Status',
			'app_version' => 'App Version',
			'app_message' => 'App Message',
			'app_purchase_code' => 'App Purchase Code',
			'is_maintance' => 'Is Maintance',
			'id' => 'ID',
			'serverkey' => 'Serverkey',
			'productid' => 'Productid',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('app_name',$this->app_name,true);
		$criteria->compare('admob_banner_id',$this->admob_banner_id,true);
		$criteria->compare('admob_interstitial_id',$this->admob_interstitial_id,true);
		$criteria->compare('admob_rewarded_id',$this->admob_rewarded_id,true);
		$criteria->compare('admob_status',$this->admob_status);
		$criteria->compare('app_version',$this->app_version);
		$criteria->compare('app_message',$this->app_message,true);
		$criteria->compare('app_purchase_code',$this->app_purchase_code,true);
		$criteria->compare('is_maintance',$this->is_maintance);
		$criteria->compare('id',$this->id);
		$criteria->compare('serverkey',$this->serverkey,true);
		$criteria->compare('productid',$this->productid,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Configs the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
