<?php

/**
 * This is the model class for table "meta_tags".
 *
 * The followings are the available columns in table 'meta_tags':
 * @property string $og_type
 * @property string $og_url
 * @property string $og_site_name
 * @property string $og_title
 * @property string $og_image
 * @property string $og_description
 * @property string $description
 * @property integer $id
 */
class MetaTags extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'meta_tags';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('og_type, og_url, og_site_name, og_title, og_image, og_description, description', 'required'),
			array('og_type', 'length', 'max'=>50),
			array('og_url', 'length', 'max'=>225),
			array('og_site_name, og_title', 'length', 'max'=>100),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('og_type, og_url, og_site_name, og_title, og_image, og_description, description, id', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'og_type' => 'Og Type',
			'og_url' => 'Og Url',
			'og_site_name' => 'Og Site Name',
			'og_title' => 'Og Title',
			'og_image' => 'Og Image',
			'og_description' => 'Og Description',
			'description' => 'Description',
			'id' => 'ID',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('og_type',$this->og_type,true);
		$criteria->compare('og_url',$this->og_url,true);
		$criteria->compare('og_site_name',$this->og_site_name,true);
		$criteria->compare('og_title',$this->og_title,true);
		$criteria->compare('og_image',$this->og_image,true);
		$criteria->compare('og_description',$this->og_description,true);
		$criteria->compare('description',$this->description,true);
		$criteria->compare('id',$this->id);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return MetaTags the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
