<?php

/**
 * This is the model class for table "pack".
 *
 * The followings are the available columns in table 'pack':
 * @property integer $id
 * @property string $title
 * @property string $identifier
 * @property string $publisher
 * @property string $publisher_website
 * @property string $privacy_policy_website
 * @property string $license_agreement_website
 *
 * The followings are the available model relations:
 * @property Sticker[] $stickers
 * @property Stickers[] $stickers1
 * @property Tray[] $trays
 */
class Pack extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pack';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('title, identifier', 'required'),
			array('title', 'length', 'max'=>100),
			array('identifier, publisher, publisher_website, privacy_policy_website, license_agreement_website', 'length', 'max'=>225),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, title, identifier, publisher, publisher_website, privacy_policy_website, license_agreement_website', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'stickers' => array(self::HAS_MANY, 'Sticker', 'category'),
			'stickers1' => array(self::HAS_MANY, 'Stickers', 'category'),
			'trays' => array(self::HAS_MANY, 'Tray', 'pack'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'title' => 'Title',
			'identifier' => 'Identifier',
			'publisher' => 'Publisher',
			'publisher_website' => 'Publisher Website',
			'privacy_policy_website' => 'Privacy Policy Website',
			'license_agreement_website' => 'License Agreement Website',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('title',$this->title,true);
		$criteria->compare('identifier',$this->identifier,true);
		$criteria->compare('publisher',$this->publisher,true);
		$criteria->compare('publisher_website',$this->publisher_website,true);
		$criteria->compare('privacy_policy_website',$this->privacy_policy_website,true);
		$criteria->compare('license_agreement_website',$this->license_agreement_website,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Pack the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
