<?php

/**
 * This is the model class for table "settings".
 *
 * The followings are the available columns in table 'settings':
 * @property integer $id
 * @property string $app_name
 * @property string $app_logo
 * @property string $app_email
 * @property string $app_website
 * @property string $app_description
 * @property string $app_token_key
 * @property string $app_token_value
 * @property string $app_terms
 * @property string $app_privacy
 * @property string $google_play_link
 * @property string $ios_app_store_link
 * @property integer $ad_status
 * @property integer $version
 * @property string $message
 */
class Settings extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'settings';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('app_name, app_logo, app_email, app_website, app_description, app_token_key, app_token_value, app_terms, app_privacy', 'required'),
			array('ad_status, version', 'numerical', 'integerOnly'=>true),
			array('app_name, app_email, app_website, message', 'length', 'max'=>255),
			array('google_play_link, ios_app_store_link', 'length', 'max'=>400),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, app_name, app_logo, app_email, app_website, app_description, app_token_key, app_token_value, app_terms, app_privacy, google_play_link, ios_app_store_link, ad_status, version, message', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'app_name' => 'App Name',
			'app_logo' => 'App Logo',
			'app_email' => 'App Email',
			'app_website' => 'App Website',
			'app_description' => 'App Description',
			'app_token_key' => 'App Token Key',
			'app_token_value' => 'App Token Value',
			'app_terms' => 'App Terms',
			'app_privacy' => 'App Privacy',
			'google_play_link' => 'Google Play Link',
			'ios_app_store_link' => 'Ios App Store Link',
			'ad_status' => 'Ad Status',
			'version' => 'Version',
			'message' => 'Message',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('app_name',$this->app_name,true);
		$criteria->compare('app_logo',$this->app_logo,true);
		$criteria->compare('app_email',$this->app_email,true);
		$criteria->compare('app_website',$this->app_website,true);
		$criteria->compare('app_description',$this->app_description,true);
		$criteria->compare('app_token_key',$this->app_token_key,true);
		$criteria->compare('app_token_value',$this->app_token_value,true);
		$criteria->compare('app_terms',$this->app_terms,true);
		$criteria->compare('app_privacy',$this->app_privacy,true);
		$criteria->compare('google_play_link',$this->google_play_link,true);
		$criteria->compare('ios_app_store_link',$this->ios_app_store_link,true);
		$criteria->compare('ad_status',$this->ad_status);
		$criteria->compare('version',$this->version);
		$criteria->compare('message',$this->message,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Settings the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
