<?php

/**
 * This is the model class for table "site_slider".
 *
 * The followings are the available columns in table 'site_slider':
 * @property integer $site_slider_id
 * @property string $site_slider_title
 * @property string $site_slider_desc
 * @property string $site_slider_button_title
 * @property string $site_slider_image
 * @property string $site_slider_background_color
 */
class SiteSlider extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'site_slider';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('site_slider_title, site_slider_desc, site_slider_button_title, site_slider_image, site_slider_background_color', 'required'),
			array('site_slider_title', 'length', 'max'=>255),
			array('site_slider_button_title, site_slider_background_color', 'length', 'max'=>100),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('site_slider_id, site_slider_title, site_slider_desc, site_slider_button_title, site_slider_image, site_slider_background_color', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'site_slider_id' => 'Site Slider',
			'site_slider_title' => 'Title',
			'site_slider_desc' => 'Desc',
			'site_slider_button_title' => 'Button Link',
			'site_slider_image' => 'Image',
			'site_slider_background_color' => 'Background Color',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('site_slider_id',$this->site_slider_id);
		$criteria->compare('site_slider_title',$this->site_slider_title,true);
		$criteria->compare('site_slider_desc',$this->site_slider_desc,true);
		$criteria->compare('site_slider_button_title',$this->site_slider_button_title,true);
		$criteria->compare('site_slider_image',$this->site_slider_image,true);
		$criteria->compare('site_slider_background_color',$this->site_slider_background_color,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return SiteSlider the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
