<?php

/**
 * This is the model class for table "sticker".
 *
 * The followings are the available columns in table 'sticker':
 * @property integer $id
 * @property string $identifier
 * @property string $tags
 * @property string $tag
 * @property string $title
 * @property string $stickers
 * @property string $icons
 * @property integer $category
 * @property integer $premium
 * @property integer $status
 * @property integer $views
 * @property integer $downloads
 *
 * The followings are the available model relations:
 * @property Pack $category0
 */
class Sticker extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'sticker';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('tags, tag, title, stickers, icons, category', 'required'),
			array('category, premium, status, views, downloads', 'numerical', 'integerOnly'=>true),
			array('identifier', 'length', 'max'=>50),
			array('tags', 'length', 'max'=>400),
			array('tag, title', 'length', 'max'=>100),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, identifier, tags, tag, title, stickers, icons, category, premium, status, views, downloads', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'category0' => array(self::BELONGS_TO, 'Pack', 'category'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'identifier' => 'Identifier',
			'tags' => 'Tags',
			'tag' => 'Tag',
			'title' => 'Title',
			'stickers' => 'Stickers',
			'icons' => 'Icons',
			'category' => 'Category',
			'premium' => 'Premium',
			'status' => 'Status',
			'views' => 'Views',
			'downloads' => 'Downloads',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('identifier',$this->identifier,true);
		$criteria->compare('tags',$this->tags,true);
		$criteria->compare('tag',$this->tag,true);
		$criteria->compare('title',$this->title,true);
		$criteria->compare('stickers',$this->stickers,true);
		$criteria->compare('icons',$this->icons,true);
		$criteria->compare('category',$this->category);
		$criteria->compare('premium',$this->premium);
		$criteria->compare('status',$this->status);
		$criteria->compare('views',$this->views);
		$criteria->compare('downloads',$this->downloads);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Sticker the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
