<?php

/**
 * This is the model class for table "stickers".
 *
 * The followings are the available columns in table 'stickers':
 * @property integer $id
 * @property string $image
 * @property string $title
 * @property integer $category
 * @property string $created
 * @property string $updated
 * @property integer $download
 * @property integer $view
 * @property integer $status
 * @property integer $price
 *
 * The followings are the available model relations:
 * @property Pack $category0
 */
class Stickers extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'stickers';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('image, title, category, created, updated', 'required'),
			array('category, download, view, status, price', 'numerical', 'integerOnly'=>true),
			array('title', 'length', 'max'=>225),
			array('created, updated', 'length', 'max'=>100),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, image, title, category, created, updated, download, view, status, price', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'category0' => array(self::BELONGS_TO, 'Pack', 'category'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'image' => 'Image',
			'title' => 'Title',
			'category' => 'Category',
			'created' => 'Created',
			'updated' => 'Updated',
			'download' => 'Download',
			'view' => 'View',
			'status' => 'Status',
			'price' => 'Price',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('image',$this->image,true);
		$criteria->compare('title',$this->title,true);
		$criteria->compare('category',$this->category);
		$criteria->compare('created',$this->created,true);
		$criteria->compare('updated',$this->updated,true);
		$criteria->compare('download',$this->download);
		$criteria->compare('view',$this->view);
		$criteria->compare('status',$this->status);
		$criteria->compare('price',$this->price);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Stickers the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
